aboutsummaryrefslogtreecommitdiffstats
path: root/core/isolinux.asm
diff options
context:
space:
mode:
authorH. Peter Anvin <hpa@zytor.com>2009-05-13 22:46:25 -0700
committerH. Peter Anvin <hpa@zytor.com>2009-05-13 22:46:25 -0700
commit4cc0c3ab6541753b89cba58c345c0cae8c7d151d (patch)
treefb8904a1e48da982a6fe3eb105a5c8be20c5a342 /core/isolinux.asm
parent95a461a83adf65aa5689b65f85330ce970121f56 (diff)
downloadsyslinux-4cc0c3ab6541753b89cba58c345c0cae8c7d151d.tar.gz
core: rename .text, .data and .bss to .text16, .data16, .bss16unify-pm
Rename the .text, .data and .bss sections to .text16, .data16 and .bss16, in anticipation of being linked with compiler-generated 32-bit code, which presumably would like to use the standard section names. Signed-off-by: H. Peter Anvin <hpa@zytor.com>
Diffstat (limited to 'core/isolinux.asm')
-rw-r--r--core/isolinux.asm8
1 files changed, 4 insertions, 4 deletions
diff --git a/core/isolinux.asm b/core/isolinux.asm
index 9183b352..4edee62c 100644
--- a/core/isolinux.asm
+++ b/core/isolinux.asm
@@ -101,7 +101,7 @@ trackbuf resb trackbufsize ; Track buffer goes here
; ends at 2800h
; Some of these are touched before the whole image
; is loaded. DO NOT move this to .bss/.uibss.
section .earlybss
alignb 4
ISOFileName resb 64 ; ISO filename canonicalization buffer
@@ -197,7 +197,7 @@ dsp_dummy: resb 1 ; Scratch, safe to overwrite
_spec_end equ $
_spec_len equ _spec_end - _spec_start
- section .bss
+ section .bss16
alignb open_file_t_size
Files resb MAX_OPEN*open_file_t_size
@@ -1079,7 +1079,7 @@ rl_checkpt equ $ ; Must be <= 800h
; End of code and data that have to be in the first sector
; ----------------------------------------------------------------------------
- section .text
+ section .text16
all_read:
@@ -1722,7 +1722,7 @@ getfssec:
; Begin data section
; -----------------------------------------------------------------------------
- section .data
+ section .data16
default_str db 'default', 0
default_len equ ($-default_str)
@@ -101,7 +101,7 @@ trackbuf resb trackbufsize ; Track buffer goes here
; ends at 2800h
; Some of these are touched before the whole image
- ; is loaded. DO NOT move this to .bss/.uibss.
+ ; is loaded. DO NOT move this to .bss16/.uibss.
section .earlybss
alignb 4